pub struct StreamComponentMetricsRequest {
pub interval_ms: i32,
pub metric: i32,
}Fields
interval_ms: i32Update interval in milliseconds
metric: i32Implementations
Sourceimpl StreamComponentMetricsRequest
impl StreamComponentMetricsRequest
Sourcepub fn metric(&self) -> MetricName
pub fn metric(&self) -> MetricName
Returns the enum value of metric, or the default if the field is set to an invalid enum value.
Sourcepub fn set_metric(&mut self, value: MetricName)
pub fn set_metric(&mut self, value: MetricName)
Sets metric to the provided enum value.